==> dxde_1.40.6-1.tar.gz: BUILD/src/gui/filters/jizdafilter.cpp <==
/***************************************************************
 * Name:      jizdafilter.cpp
 * Author:    David Vachulka (arch_dvx@users.sourceforge.net)
 * Copyright: 2018
 * License:   GPL3
 **************************************************************/

#include <wx/gbsizer.h>
#include "jizdafilter.h"
#include "utils/dxutils.h"
#include "utils/dxsettings.h"
#include "model/dbmodel.h"

IMPLEMENT_DYNAMIC_CLASS(JizdaFilter, wxDialog)

BEGIN_EVENT_TABLE(JizdaFilter, wxDialog)
    EVT_BUTTON(wxID_OK, JizdaFilter::OnOk)
    EVT_BUTTON(wxID_CANCEL, JizdaFilter::OnCancel)
END_EVENT_TABLE()

JizdaFilter::JizdaFilter(wxWindow *parent)
    : wxDialog(parent, wxID_ANY, wxString::FromUTF8("Filtr pro knihu jízd"))
{
    m_filters.Add(Filter(FA_LESS, false, dxsettings.datum()));
    m_filters.Add(Filter(FA_EQUAL, false, wxEmptyString));
    m_filters.Add(Filter(FA_EQUAL, false, wxEmptyString));
    m_filters.Add(Filter(FA_LESS, false, 0));
    m_filters.Add(Filter(FA_EQUAL, false, wxEmptyString));
    m_filters.Add(Filter(FA_EQUAL, false, wxEmptyString));
    createControls();
    fillControls();
    m_mainSizer->Fit(this);
    m_mainSizer->SetSizeHints(this);
}

JizdaFilter::JizdaFilter(wxWindow *parent, dxFilterArray filters)
    : wxDialog(parent, wxID_ANY, wxString::FromUTF8("Filtr pro knihu jízd")), m_filters(filters)
{
    createControls();
    fillControls();
    m_mainSizer->Fit(this);
    m_mainSizer->SetSizeHints(this);
}

dxFilterArray JizdaFilter::filters() const
{
    return m_filters;
}

void JizdaFilter::createControls()
{
    int i = 0; //row

    m_mainSizer = new wxBoxSizer(wxVERTICAL);

    wxGridBagSizer *gridSizer = new wxGridBagSizer(5, 5);

    gridSizer->Add(new wxStaticText(this, wxID_ANY, "Datum"), wxGBPosition(i,0), wxDefaultSpan, wxALIGN_CENTER_VERTICAL);
    m_datumAction = new wxChoice(this, wxID_ANY);
    m_datumAction->Append(wxString::FromUTF8("Starší než"), new FilterAction(FA_LESS));
    m_datumAction->Append(wxString::FromUTF8("Starší než nebo rovné"), new FilterAction(FA_LESSEQUAL));
    m_datumAction->Append("Rovné", new FilterAction(FA_EQUAL));
    m_datumAction->Append(wxString::FromUTF8("Novější než nebo rovné"), new FilterAction(FA_GREATEREQUAL));
    m_datumAction->Append(wxString::FromUTF8("Novější než"), new FilterAction(FA_GREATER));
    gridSizer->Add(m_datumAction, wxGBPosition(i,1), wxDefaultSpan, wxEXPAND);
    m_datumValue = new wxDatePickerCtrl(this, wxID_ANY, dxsettings.datum(), wxDefaultPosition, wxDefaultSize, wxDP_DROPDOWN|wxDP_SHOWCENTURY);
    m_datumValue->SetRange(wxDateTime(1,wxDateTime::Jan,idbmodel->currentRok()), wxDateTime(31,wxDateTime::Dec,idbmodel->currentRok()));
    gridSizer->Add(m_datumValue, wxGBPosition(i,2), wxDefaultSpan, wxEXPAND);
    m_datumUsage = new wxCheckBox(this, wxID_ANY, wxEmptyString);
    gridSizer->Add(m_datumUsage, wxGBPosition(i,3), wxDefaultSpan, wxEXPAND);
    i++;

    gridSizer->Add(new wxStaticText(this, wxID_ANY, "Cesta"), wxGBPosition(i,0), wxDefaultSpan, wxALIGN_CENTER_VERTICAL);
    m_cestaAction = new wxChoice(this, wxID_ANY);
    m_cestaAction->Append("Rovno", new FilterAction(FA_EQUAL));
    m_cestaAction->Append("Obsahuje", new FilterAction(FA_CONTAINS));
    gridSizer->Add(m_cestaAction, wxGBPosition(i,1), wxDefaultSpan, wxEXPAND);
    m_cestaValue = new wxTextCtrl(this, wxID_ANY);
    gridSizer->Add(m_cestaValue, wxGBPosition(i,2), wxDefaultSpan, wxEXPAND);
    m_cestaUsage = new wxCheckBox(this, wxID_ANY, wxEmptyString);
    gridSizer->Add(m_cestaUsage, wxGBPosition(i,3), wxDefaultSpan, wxEXPAND);
    i++;

    gridSizer->Add(new wxStaticText(this, wxID_ANY, wxString::FromUTF8("Účel")), wxGBPosition(i,0), wxDefaultSpan, wxALIGN_CENTER_VERTICAL);
    m_ucelAction = new wxChoice(this, wxID_ANY);
    m_ucelAction->Append("Rovno", new FilterAction(FA_EQUAL));
    m_ucelAction->Append("Obsahuje", new FilterAction(FA_CONTAINS));
    gridSizer->Add(m_ucelAction, wxGBPosition(i,1), wxDefaultSpan, wxEXPAND);
    m_ucelValue = new wxTextCtrl(this, wxID_ANY);
    gridSizer->Add(m_ucelValue, wxGBPosition(i,2), wxDefaultSpan, wxEXPAND);
    m_ucelUsage = new wxCheckBox(this, wxID_ANY, wxEmptyString);
    gridSizer->Add(m_ucelUsage, wxGBPosition(i,3), wxDefaultSpan, wxEXPAND);
    i++;

    gridSizer->Add(new wxStaticText(this, wxID_ANY, "km"), wxGBPosition(i,0), wxDefaultSpan, wxALIGN_CENTER_VERTICAL);
    m_kmAction = new wxChoice(this, wxID_ANY);
    m_kmAction->Append(wxString::FromUTF8("Menší než"), new FilterAction(FA_LESS));
    m_kmAction->Append(wxString::FromUTF8("Menší než nebo rovno"), new FilterAction(FA_LESSEQUAL));
    m_kmAction->Append("Rovno", new FilterAction(FA_EQUAL));
    m_kmAction->Append(wxString::FromUTF8("Větší než nebo rovno"), new FilterAction(FA_GREATEREQUAL));
    m_kmAction->Append(wxString::FromUTF8("Větší než"), new FilterAction(FA_GREATER));
    gridSizer->Add(m_kmAction, wxGBPosition(i,1), wxDefaultSpan, wxEXPAND);
    m_kmValue = new wxSpinCtrl(this, wxID_ANY);
    m_kmValue->SetRange(0, 10000);
    gridSizer->Add(m_kmValue, wxGBPosition(i,2), wxDefaultSpan, wxEXPAND);
    m_kmUsage = new wxCheckBox(this, wxID_ANY, wxEmptyString);
    gridSizer->Add(m_kmUsage, wxGBPosition(i,3), wxDefaultSpan, wxEXPAND);
    i++;

    gridSizer->Add(new wxStaticText(this, wxID_ANY, "Vozidlo"), wxGBPosition(i,0), wxDefaultSpan, wxALIGN_CENTER_VERTICAL);
    m_vozidloAction = new wxChoice(this, wxID_ANY);
    m_vozidloAction->Append("Rovno", new FilterAction(FA_EQUAL));
    m_vozidloAction->Append("Obsahuje", new FilterAction(FA_CONTAINS));
    gridSizer->Add(m_vozidloAction, wxGBPosition(i,1), wxDefaultSpan, wxEXPAND);
    m_vozidloValue = new wxTextCtrl(this, wxID_ANY);
    gridSizer->Add(m_vozidloValue, wxGBPosition(i,2), wxDefaultSpan, wxEXPAND);
    m_vozidloUsage = new wxCheckBox(this, wxID_ANY, wxEmptyString);
    gridSizer->Add(m_vozidloUsage, wxGBPosition(i,3), wxDefaultSpan, wxEXPAND);
    i++;

    gridSizer->Add(new wxStaticText(this, wxID_ANY, wxString::FromUTF8("Řidič")), wxGBPosition(i,0), wxDefaultSpan, wxALIGN_CENTER_VERTICAL);
    m_ridicAction = new wxChoice(this, wxID_ANY);
    m_ridicAction->Append("Rovno", new FilterAction(FA_EQUAL));
    m_ridicAction->Append("Obsahuje", new FilterAction(FA_CONTAINS));
    gridSizer->Add(m_ridicAction, wxGBPosition(i,1), wxDefaultSpan, wxEXPAND);
    m_ridicValue = new wxTextCtrl(this, wxID_ANY);
    gridSizer->Add(m_ridicValue, wxGBPosition(i,2), wxDefaultSpan, wxEXPAND);
    m_ridicUsage = new wxCheckBox(this, wxID_ANY, wxEmptyString);
    gridSizer->Add(m_ridicUsage, wxGBPosition(i,3), wxDefaultSpan, wxEXPAND);

    m_mainSizer->Add(gridSizer, 0, wxALL|wxALIGN_CENTER_HORIZONTAL, 5);

    wxStdDialogButtonSizer *btnSizer = new wxStdDialogButtonSizer();
    wxButton* okButton = new wxButton(this, wxID_OK, "", wxDefaultPosition, wxDefaultSize, 0);
    btnSizer->AddButton(okButton);
    wxButton* cancelButton = new wxButton(this, wxID_CANCEL, "", wxDefaultPosition, wxDefaultSize, 0);
    btnSizer->AddButton(cancelButton);
    btnSizer->Realize();
    m_mainSizer->Add(btnSizer, 0, wxALL|wxALIGN_CENTER_HORIZONTAL, 5);

    this->SetSizer(m_mainSizer);
}

void JizdaFilter::fillControls()
{
    if(m_filters.GetCount() == 6)
    {
        if(m_filters[0].type() == FT_DATUM)
        {
            m_datumAction->SetSelection(m_filters[0].action());
            m_datumValue->SetValue(m_filters[0].datum());
            m_datumUsage->SetValue(m_filters[0].active());
        }
        if(m_filters[1].type() == FT_TEXT)
        {
            m_cestaAction->SetSelection(m_filters[1].action()==FA_EQUAL?0:1);
            m_cestaValue->ChangeValue(m_filters[1].text());
            m_cestaUsage->SetValue(m_filters[1].active());
        }
        if(m_filters[2].type() == FT_TEXT)
        {
            m_ucelAction->SetSelection(m_filters[2].action()==FA_EQUAL?0:1);
            m_ucelValue->ChangeValue(m_filters[2].text());
            m_ucelUsage->SetValue(m_filters[2].active());
        }
        if(m_filters[3].type() == FT_INTEGER)
        {
            m_kmAction->SetSelection(m_filters[3].action());
            m_kmValue->SetValue(m_filters[3].intvalue());
            m_kmUsage->SetValue(m_filters[3].active());
        }
        if(m_filters[4].type() == FT_TEXT)
        {
            m_vozidloAction->SetSelection(m_filters[4].action()==FA_EQUAL?0:1);
            m_vozidloValue->ChangeValue(m_filters[4].text());
            m_vozidloUsage->SetValue(m_filters[4].active());
        }
        if(m_filters[5].type() == FT_TEXT)
        {
            m_ridicAction->SetSelection(m_filters[5].action()==FA_EQUAL?0:1);
            m_ridicValue->ChangeValue(m_filters[5].text());
            m_ridicUsage->SetValue(m_filters[5].active());
        }
    }
}

void JizdaFilter::OnOk(wxCommandEvent& /*event*/)
{
    m_filters[0].setAction(*static_cast<FilterAction*>(m_datumAction->GetClientData(static_cast<unsigned int>(m_datumAction->GetSelection()))));
    m_filters[0].setDatum(m_datumValue->GetValue());
    m_filters[0].setActive(m_datumUsage->GetValue());

    m_filters[1].setAction(*static_cast<FilterAction*>(m_cestaAction->GetClientData(static_cast<unsigned int>(m_cestaAction->GetSelection()))));
    m_filters[1].setText(m_cestaValue->GetValue());
    m_filters[1].setActive(m_cestaUsage->GetValue());

    m_filters[2].setAction(*static_cast<FilterAction*>(m_ucelAction->GetClientData(static_cast<unsigned int>(m_ucelAction->GetSelection()))));
    m_filters[2].setText(m_ucelValue->GetValue());
    m_filters[2].setActive(m_ucelUsage->GetValue());

    m_filters[3].setAction(*static_cast<FilterAction*>(m_kmAction->GetClientData(static_cast<unsigned int>(m_kmAction->GetSelection()))));
    m_filters[3].setIntvalue(m_kmValue->GetValue());
    m_filters[3].setActive(m_kmUsage->GetValue());

    m_filters[4].setAction(*static_cast<FilterAction*>(m_vozidloAction->GetClientData(static_cast<unsigned int>(m_vozidloAction->GetSelection()))));
    m_filters[4].setText(m_vozidloValue->GetValue());
    m_filters[4].setActive(m_vozidloUsage->GetValue());

    m_filters[5].setAction(*static_cast<FilterAction*>(m_ridicAction->GetClientData(static_cast<unsigned int>(m_ridicAction->GetSelection()))));
    m_filters[5].setText(m_ridicValue->GetValue());
    m_filters[5].setActive(m_ridicUsage->GetValue());

    EndModal(wxID_OK);
}

void JizdaFilter::OnCancel(wxCommandEvent& /*event*/)
{
    EndModal(wxID_CANCEL);
}

==> dxde_1.40.12-1.tar.gz: BUILD/src/gui/filters/jizdafilter.cpp <==
/***************************************************************
 * Name:      jizdafilter.cpp
 * Author:    David Vachulka (archdvx@dxsolutions.org)
 * Copyright: 2018
 * License:   GPL3
 **************************************************************/

#include <wx/gbsizer.h>
#include "jizdafilter.h"
#include "utils/dxutils.h"
#include "utils/dxsettings.h"
#include "model/dbmodel.h"

IMPLEMENT_DYNAMIC_CLASS(JizdaFilter, wxDialog)

BEGIN_EVENT_TABLE(JizdaFilter, wxDialog)
    EVT_BUTTON(wxID_OK, JizdaFilter::OnOk)
    EVT_BUTTON(wxID_CANCEL, JizdaFilter::OnCancel)
END_EVENT_TABLE()

JizdaFilter::JizdaFilter(wxWindow *parent)
    : wxDialog(parent, wxID_ANY, wxString::FromUTF8("Filtr pro knihu jízd"))
{
    m_filters.Add(Filter(FA_LESS, false, dxsettings.datum()));
    m_filters.Add(Filter(FA_EQUAL, false, wxEmptyString));
    m_filters.Add(Filter(FA_EQUAL, false, wxEmptyString));
    m_filters.Add(Filter(FA_LESS, false, 0));
    m_filters.Add(Filter(FA_EQUAL, false, wxEmptyString));
    m_filters.Add(Filter(FA_EQUAL, false, wxEmptyString));
    createControls();
    fillControls();
    m_mainSizer->Fit(this);
    m_mainSizer->SetSizeHints(this);
}

JizdaFilter::JizdaFilter(wxWindow *parent, dxFilterArray filters)
    : wxDialog(parent, wxID_ANY, wxString::FromUTF8("Filtr pro knihu jízd")), m_filters(filters)
{
    createControls();
    fillControls();
    m_mainSizer->Fit(this);
    m_mainSizer->SetSizeHints(this);
}

dxFilterArray JizdaFilter::filters() const
{
    return m_filters;
}

void JizdaFilter::createControls()
{
    int i = 0; //row

    m_mainSizer = new wxBoxSizer(wxVERTICAL);

    wxGridBagSizer *gridSizer = new wxGridBagSizer(5, 5);

    gridSizer->Add(new wxStaticText(this, wxID_ANY, "Datum"), wxGBPosition(i,0), wxDefaultSpan, wxALIGN_CENTER_VERTICAL);
    m_datumAction = new wxChoice(this, wxID_ANY);
    m_datumAction->Append(wxString::FromUTF8("Starší než"), new FilterAction(FA_LESS));
    m_datumAction->Append(wxString::FromUTF8("Starší než nebo rovné"), new FilterAction(FA_LESSEQUAL));
    m_datumAction->Append(wxString::FromUTF8("Rovné"), new FilterAction(FA_EQUAL));
    m_datumAction->Append(wxString::FromUTF8("Novější než nebo rovné"), new FilterAction(FA_GREATEREQUAL));
    m_datumAction->Append(wxString::FromUTF8("Novější než"), new FilterAction(FA_GREATER));
    gridSizer->Add(m_datumAction, wxGBPosition(i,1), wxDefaultSpan, wxEXPAND);
    m_datumValue = new wxDatePickerCtrl(this, wxID_ANY, dxsettings.datum(), wxDefaultPosition, wxDefaultSize, wxDP_DROPDOWN|wxDP_SHOWCENTURY);
    m_datumValue->SetRange(wxDateTime(1,wxDateTime::Jan,idbmodel->currentRok()), wxDateTime(31,wxDateTime::Dec,idbmodel->currentRok()));
    gridSizer->Add(m_datumValue, wxGBPosition(i,2), wxDefaultSpan, wxEXPAND);
    m_datumUsage = new wxCheckBox(this, wxID_ANY, wxEmptyString);
    gridSizer->Add(m_datumUsage, wxGBPosition(i,3), wxDefaultSpan, wxEXPAND);
    i++;

    gridSizer->Add(new wxStaticText(this, wxID_ANY, "Cesta"), wxGBPosition(i,0), wxDefaultSpan, wxALIGN_CENTER_VERTICAL);
    m_cestaAction = new wxChoice(this, wxID_ANY);
    m_cestaAction->Append("Rovno", new FilterAction(FA_EQUAL));
    m_cestaAction->Append("Obsahuje", new FilterAction(FA_CONTAINS));
    gridSizer->Add(m_cestaAction, wxGBPosition(i,1), wxDefaultSpan, wxEXPAND);
    m_cestaValue = new wxTextCtrl(this, wxID_ANY);
    gridSizer->Add(m_cestaValue, wxGBPosition(i,2), wxDefaultSpan, wxEXPAND);
    m_cestaUsage = new wxCheckBox(this, wxID_ANY, wxEmptyString);
    gridSizer->Add(m_cestaUsage, wxGBPosition(i,3), wxDefaultSpan, wxEXPAND);
    i++;

    gridSizer->Add(new wxStaticText(this, wxID_ANY, wxString::FromUTF8("Účel")), wxGBPosition(i,0), wxDefaultSpan, wxALIGN_CENTER_VERTICAL);
    m_ucelAction = new wxChoice(this, wxID_ANY);
    m_ucelAction->Append("Rovno", new FilterAction(FA_EQUAL));
    m_ucelAction->Append("Obsahuje", new FilterAction(FA_CONTAINS));
    gridSizer->Add(m_ucelAction, wxGBPosition(i,1), wxDefaultSpan, wxEXPAND);
    m_ucelValue = new wxTextCtrl(this, wxID_ANY);
    gridSizer->Add(m_ucelValue, wxGBPosition(i,2), wxDefaultSpan, wxEXPAND);
    m_ucelUsage = new wxCheckBox(this, wxID_ANY, wxEmptyString);
    gridSizer->Add(m_ucelUsage, wxGBPosition(i,3), wxDefaultSpan, wxEXPAND);
    i++;

    gridSizer->Add(new wxStaticText(this, wxID_ANY, "km"), wxGBPosition(i,0), wxDefaultSpan, wxALIGN_CENTER_VERTICAL);
    m_kmAction = new wxChoice(this, wxID_ANY);
    m_kmAction->Append(wxString::FromUTF8("Menší než"), new FilterAction(FA_LESS));
    m_kmAction->Append(wxString::FromUTF8("Menší než nebo rovno"), new FilterAction(FA_LESSEQUAL));
    m_kmAction->Append("Rovno", new FilterAction(FA_EQUAL));
    m_kmAction->Append(wxString::FromUTF8("Větší než nebo rovno"), new FilterAction(FA_GREATEREQUAL));
    m_kmAction->Append(wxString::FromUTF8("Větší než"), new FilterAction(FA_GREATER));
    gridSizer->Add(m_kmAction, wxGBPosition(i,1), wxDefaultSpan, wxEXPAND);
    m_kmValue = new wxSpinCtrl(this, wxID_ANY);
    m_kmValue->SetRange(0, 10000);
    gridSizer->Add(m_kmValue, wxGBPosition(i,2), wxDefaultSpan, wxEXPAND);
    m_kmUsage = new wxCheckBox(this, wxID_ANY, wxEmptyString);
    gridSizer->Add(m_kmUsage, wxGBPosition(i,3), wxDefaultSpan, wxEXPAND);
    i++;

    gridSizer->Add(new wxStaticText(this, wxID_ANY, "Vozidlo"), wxGBPosition(i,0), wxDefaultSpan, wxALIGN_CENTER_VERTICAL);
    m_vozidloAction = new wxChoice(this, wxID_ANY);
    m_vozidloAction->Append("Rovno", new FilterAction(FA_EQUAL));
    m_vozidloAction->Append("Obsahuje", new FilterAction(FA_CONTAINS));
    gridSizer->Add(m_vozidloAction, wxGBPosition(i,1), wxDefaultSpan, wxEXPAND);
    m_vozidloValue = new wxTextCtrl(this, wxID_ANY);
    gridSizer->Add(m_vozidloValue, wxGBPosition(i,2), wxDefaultSpan, wxEXPAND);
    m_vozidloUsage = new wxCheckBox(this, wxID_ANY, wxEmptyString);
    gridSizer->Add(m_vozidloUsage, wxGBPosition(i,3), wxDefaultSpan, wxEXPAND);
    i++;

    gridSizer->Add(new wxStaticText(this, wxID_ANY, wxString::FromUTF8("Řidič")), wxGBPosition(i,0), wxDefaultSpan, wxALIGN_CENTER_VERTICAL);
    m_ridicAction = new wxChoice(this, wxID_ANY);
    m_ridicAction->Append("Rovno", new FilterAction(FA_EQUAL));
    m_ridicAction->Append("Obsahuje", new FilterAction(FA_CONTAINS));
    gridSizer->Add(m_ridicAction, wxGBPosition(i,1), wxDefaultSpan, wxEXPAND);
    m_ridicValue = new wxTextCtrl(this, wxID_ANY);
    gridSizer->Add(m_ridicValue, wxGBPosition(i,2), wxDefaultSpan, wxEXPAND);
    m_ridicUsage = new wxCheckBox(this, wxID_ANY, wxEmptyString);
    gridSizer->Add(m_ridicUsage, wxGBPosition(i,3), wxDefaultSpan, wxEXPAND);

    m_mainSizer->Add(gridSizer, 0, wxALL|wxALIGN_CENTER_HORIZONTAL, 5);

    wxStdDialogButtonSizer *btnSizer = new wxStdDialogButtonSizer();
    wxButton* okButton = new wxButton(this, wxID_OK, "", wxDefaultPosition, wxDefaultSize, 0);
    btnSizer->AddButton(okButton);
    wxButton* cancelButton = new wxButton(this, wxID_CANCEL, "", wxDefaultPosition, wxDefaultSize, 0);
    btnSizer->AddButton(cancelButton);
    btnSizer->Realize();
    m_mainSizer->Add(btnSizer, 0, wxALL|wxALIGN_CENTER_HORIZONTAL, 5);

    this->SetSizer(m_mainSizer);
}

void JizdaFilter::fillControls()
{
    if(m_filters.GetCount() == 6)
    {
        if(m_filters[0].type() == FT_DATUM)
        {
            m_datumAction->SetSelection(m_filters[0].action());
            m_datumValue->SetValue(m_filters[0].datum());
            m_datumUsage->SetValue(m_filters[0].active());
        }
        if(m_filters[1].type() == FT_TEXT)
        {
            m_cestaAction->SetSelection(m_filters[1].action()==FA_EQUAL?0:1);
            m_cestaValue->ChangeValue(m_filters[1].text());
            m_cestaUsage->SetValue(m_filters[1].active());
        }
        if(m_filters[2].type() == FT_TEXT)
        {
            m_ucelAction->SetSelection(m_filters[2].action()==FA_EQUAL?0:1);
            m_ucelValue->ChangeValue(m_filters[2].text());
            m_ucelUsage->SetValue(m_filters[2].active());
        }
        if(m_filters[3].type() == FT_INTEGER)
        {
            m_kmAction->SetSelection(m_filters[3].action());
            m_kmValue->SetValue(m_filters[3].intvalue());
            m_kmUsage->SetValue(m_filters[3].active());
        }
        if(m_filters[4].type() == FT_TEXT)
        {
            m_vozidloAction->SetSelection(m_filters[4].action()==FA_EQUAL?0:1);
            m_vozidloValue->ChangeValue(m_filters[4].text());
            m_vozidloUsage->SetValue(m_filters[4].active());
        }
        if(m_filters[5].type() == FT_TEXT)
        {
            m_ridicAction->SetSelection(m_filters[5].action()==FA_EQUAL?0:1);
            m_ridicValue->ChangeValue(m_filters[5].text());
            m_ridicUsage->SetValue(m_filters[5].active());
        }
    }
}

void JizdaFilter::OnOk(wxCommandEvent& /*event*/)
{
    m_filters[0].setAction(*static_cast<FilterAction*>(m_datumAction->GetClientData(static_cast<unsigned int>(m_datumAction->GetSelection()))));
    m_filters[0].setDatum(m_datumValue->GetValue());
    m_filters[0].setActive(m_datumUsage->GetValue());

    m_filters[1].setAction(*static_cast<FilterAction*>(m_cestaAction->GetClientData(static_cast<unsigned int>(m_cestaAction->GetSelection()))));
    m_filters[1].setText(m_cestaValue->GetValue());
    m_filters[1].setActive(m_cestaUsage->GetValue());

    m_filters[2].setAction(*static_cast<FilterAction*>(m_ucelAction->GetClientData(static_cast<unsigned int>(m_ucelAction->GetSelection()))));
    m_filters[2].setText(m_ucelValue->GetValue());
    m_filters[2].setActive(m_ucelUsage->GetValue());

    m_filters[3].setAction(*static_cast<FilterAction*>(m_kmAction->GetClientData(static_cast<unsigned int>(m_kmAction->GetSelection()))));
    m_filters[3].setIntvalue(m_kmValue->GetValue());
    m_filters[3].setActive(m_kmUsage->GetValue());

    m_filters[4].setAction(*static_cast<FilterAction*>(m_vozidloAction->GetClientData(static_cast<unsigned int>(m_vozidloAction->GetSelection()))));
    m_filters[4].setText(m_vozidloValue->GetValue());
    m_filters[4].setActive(m_vozidloUsage->GetValue());

    m_filters[5].setAction(*static_cast<FilterAction*>(m_ridicAction->GetClientData(static_cast<unsigned int>(m_ridicAction->GetSelection()))));
    m_filters[5].setText(m_ridicValue->GetValue());
    m_filters[5].setActive(m_ridicUsage->GetValue());

    EndModal(wxID_OK);
}

void JizdaFilter::OnCancel(wxCommandEvent& /*event*/)
{
    EndModal(wxID_CANCEL);
}
